"""Registry nsset REST API views."""
from asgiref.sync import sync_to_async
from ninja import Router
from regal import NssetId

from ferda.api import Error, check_permissions
from ferda.backend import STATEMENTOR
from ferda.constants import LogReferenceType
from ferda.registry.record_statement import get_object_statement_pdf

from .search import router as search_router

router = Router(tags=['registry', 'nsset'])
router.add_router('search', search_router)


@router.get('/record_statement/{nsset_id}/', url_name='get_nsset_record_statement_pdf', response={
    200: bytes,
    404: Error,
})
async def get_nsset_record_statement_pdf(request, nsset_id: NssetId):
    """Get verified record statement of the nsset."""
    await sync_to_async(check_permissions)(request, permissions=['ferda.can_view_registry'])
    return await get_object_statement_pdf(
        request, NssetId(nsset_id), LogReferenceType.NSSET, STATEMENTOR.get_nsset_statement
    )
